/* LICENSE BLOCK
Part of mde: a Modular D game-oriented Engine
Copyright © 2007-2008 Diggory Hardy

This program is free software: you can redistribute it and/or modify it under the terms
of the GNU General Public License as published by the Free Software Foundation, either
version 2 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>. */

/** Interface for the renderer. This is planned to replace decoration.d */
module mde.gui.renderer.IRenderer;

/** Interface for renderers.
*
* Renderers provide unified drawing methods for widget, e.g. to draw a window background, a frame,
* or a button. The renderer will effectively be synonymous with the theme, except that a scripted
* renderer may also be available.
*
* The renderer is intended to be per-GUI. */
interface IRenderer
{
    //BEGIN Get dimensions
    /** Return the renderer's window border width. */
    int windowBorder ();
    
    /** Return the renderer's between-widget spacing (for layout widgets). */
    int layoutSpacing ();
    //END Get dimensions
    
    //BEGIN draw routines
    /** Draw a window border plus background. */
    void drawWindow (int x, int y, int w, int h);
    
    /** Draws a widget background. Usually doesn't do anything since backgrounds are transparent. */
    void drawWidgetBack (int x, int y, int w, int h);
    
    /** Draws a button frame, in if pushed == true. */
    void drawButton (int x, int y, int w, int h, bool pushed);
    //END draw routines
}
